# MFU (Michael's Fun Utilities)

A collection of utilities to make my life easier and hopefully others too.


## Release Notes

### 0.0.7
- Fixed new acumen namespace.

### 0.0.6
- Fixed pypi config.

### 0.0.5
- Moved to pyproject.toml rather than setup.py
- Added wheel in upload

### 0.0.4
- Getting sync listener to work on Windows.

### 0.0.3
- Getting mfu to work with python -m command.

### 0.0.2
- Basic improvements

### 0.0.1
- Added basic doctor and sync functions